@@ -3,7 +3,9 @@ use v5.14;
 use warnings;
 
 require Exporter;
-use Data::Dumper;
+our @ISA= qw(Exporter);
+
+use constant;
 
 our (@EXPORT_OK, %EXPORT_TAGS, %retryable);
 my (%consistency_lookup);
@@ -42,7 +44,7 @@ BEGIN {
         CONSISTENCY_EACH_QUORUM => 7,
         CONSISTENCY_SERIAL => 8,
         CONSISTENCY_LOCAL_SERIAL => 9,
-        CONSISTENCY_ONE => 10,
+        CONSISTENCY_LOCAL_ONE => 10,
 
         NO_RETRY => 0,
     );
@@ -85,9 +87,6 @@ BEGIN {
     );
 }
 
-our @ISA= qw(Exporter);
-
-
 sub unpack_string_multimap {
     my $result= {};
     my $count= unpack('n', substr $_[0], 0, 2, '');
